@@ -1,10 +1,9 @@
-package CGI::Application::Plus::Util ;
-$VERSION = 1.19 ;
+use strict ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
 
-; use strict
+; package CGI::Application::Plus::Util
 
 # same as the original, here just for compatibility
 ; sub load_tmpl
